# kemstem
`kemstem` is a python package for quantification and visualization of atomic resolution STEM data developed in the Kourkoutis Electron Microscopy group at Cornell University, based on the techniques described in:
- [Savitzky, B. H., El Baggari, I., Admasu, A. S., Kim, J., Cheong, S. W., Hovden, R., & Kourkoutis, L. F. (2017). Bending and breaking of stripes in a charge ordered manganite. Nature communications, 8(1), 1883.](https://doi.org/10.1038/s41467-017-02156-1)
- [Smeaton, M. A., El Baggari, I., Balazs, D. M., Hanrath, T., & Kourkoutis, L. F. (2021). Mapping defect relaxation in quantum dot solids upon in situ heating. ACS nano, 15(1), 719-726.](https://doi.org/10.1021/acsnano.0c06990)
- [Goodge, B. H., El Baggari, I., Hong, S. S., Wang, Z., Schlom, D. G., Hwang, H. Y., & Kourkoutis, L. F. (2022). Disentangling coexisting structural order through phase lock-in analysis of atomic-resolution STEM data. Microscopy and Microanalysis, 28(2), 404-411.](https://doi.org/10.1017/S1431927622000125)

## Installation
``kemstem`` can be installed from PyPI with pip:
`> pip install kemstem`

Or to install the development version, clone from github and install with pip:

`> git clone https://github.com/noahschnitzer/kemstem.git`
`> cd kemstem`
`> pip install -e . `

## Examples
Example jupyter notebooks with demonstration workflows can be found along with sample data under `example_notebooks`.

## Documentation
Package documentation is available [here](https://kemstem.readthedocs.io/en/latest/).

<img src="kem_logo.png" width="400">
